pub struct Project {
pub databases: Vec<Database>,
pub replacement_schemas: BTreeSet<SchemaQualifier>,
}Expand description
A fully validated compiled project.
Represents the complete validated project structure, containing all databases, schemas, and objects. This is the top-level compiled project produced after validating project source inputs.
Compiled projects are produced by crate::project::plan_sync and the
internal compiler entrypoints in crate::project::compiler.
Validation Guarantees
A successfully created Project guarantees:
- All object names match their file names
- All qualified names match the directory structure
- All supporting statements reference the correct objects
- All object types are consistent across statements
- No unsupported statement types are present
Fields
databases: Vec<Database>All validated databases in this project
replacement_schemas: BTreeSet<SchemaQualifier>Schemas that use replacement materialized views, derived from
SET api = stable statements.
Each entry is a (database, schema) pair.
Implementations
Sourceimpl Project
impl Project
Sourcepub fn rewrite_cluster_references(
&mut self,
cluster_map: &BTreeMap<String, String>,
)
pub fn rewrite_cluster_references( &mut self, cluster_map: &BTreeMap<String, String>, )
Rewrite all cluster references in the project using the given cluster name map.
Walks all objects in all databases/schemas and replaces cluster names in
IN CLUSTER clauses when the cluster name is a key in the map.
Sourcepub fn rewrite_database_references(&mut self, db_map: &BTreeMap<String, String>)
pub fn rewrite_database_references(&mut self, db_map: &BTreeMap<String, String>)
Rewrite all cross-database references in the project using the given database name map.
This walks all objects, mod_statements, etc. and replaces database names in 3-part qualified references when the database is a project-owned database that appears in the map.